Documentation Home — Askbot v0.7.43 documentation

# Askbot Project Documentation

Home | Ask Questions | Hire Us | Documentation | Contribute | Contact

# Documentation Home

Askbot is an open source Question and Answer (Q&A) forum project inspired by StackOverflow and YahooAnswers.

It is quick and easy to install and deploy askbot on your site. Have questions? - please ask at the forum or by email at admin@askbot.org

- Install the software
- Create the database
- Create and configure the site files
- Initialize the database tables
- Deploy on a webserver
- Import data (StackExchange & ZenDesk)
- Moderation
- Appendix A: Maintenance procedures
- Appendix B: Sending email to askbot
- Appendix C: Optional modules
- Appendix D: Askbot as reusable Django application
- Appendix E: Customizing skin in askbot
- Appendix F: Intranet setup
- Footnotes
- Contributors
- Changelog

Some background information: Askbot is written in Python on top of the Django platform. Code of Askbot grew out of CNPROG project originally written by Mike Chen and Sailing Cai.